from setuptools import setup, find_packages

setup(
    name='fine_calc',
    version='1.0.0',
    author='Chinmay Danwade',
    author_email='lawd7131@gmail.com',
    description='A Python library for calculating fines based on overdue days.',
    url='https://github.com/yourusername/chinmay-dhanawade',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)
